import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { SageMakerFeatureStoreRuntimeServiceException as __BaseException } from "./SageMakerFeatureStoreRuntimeServiceException";
/**
 * <p>You do not have permission to perform an action.</p>
 */
export declare class AccessForbidden extends __BaseException {
    readonly name: "AccessForbidden";
    readonly $fault: "client";
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<AccessForbidden, __BaseException>);
}
/**
 * <p>The identifier that identifies the batch of Records you are retrieving in a batch.</p>
 */
export interface BatchGetRecordIdentifier {
    /**
     * <p>A <code>FeatureGroupName</code> containing Records you are retrieving in a batch.</p>
     */
    FeatureGroupName: string | undefined;
    /**
     * <p>The value for a list of record identifiers in string format.</p>
     */
    RecordIdentifiersValueAsString: string[] | undefined;
    /**
     * <p>List of names of Features to be retrieved. If not specified, the latest value for all
     *          the Features are returned.</p>
     */
    FeatureNames?: string[];
}
export declare namespace BatchGetRecordIdentifier {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: BatchGetRecordIdentifier) => any;
}
export interface BatchGetRecordRequest {
    /**
     * <p>A list of <code>FeatureGroup</code> names, with their corresponding <code>RecordIdentifier</code> value, and Feature name
     *       that have been requested to be retrieved in batch.</p>
     */
    Identifiers: BatchGetRecordIdentifier[] | undefined;
}
export declare namespace BatchGetRecordRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: BatchGetRecordRequest) => any;
}
/**
 * <p>The error that has occurred when attempting to retrieve a batch of Records.</p>
 */
export interface BatchGetRecordError {
    /**
     * <p>The name of the feature group that the record belongs to.</p>
     */
    FeatureGroupName: string | undefined;
    /**
     * <p>The value for the <code>RecordIdentifier</code> in string format of a Record from a <code>FeatureGroup</code> that is causing
     *       an error when attempting to be retrieved.</p>
     */
    RecordIdentifierValueAsString: string | undefined;
    /**
     * <p>The error code of an error that has occured when attempting to retrieve a batch of Records. For more information on errors, see <a href="https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_feature_store_GetRecord.html#API_feature_store_GetRecord_Errors"> Errors</a>.</p>
     */
    ErrorCode: string | undefined;
    /**
     * <p>The error message of an error that has occured when attempting to retrieve a record in the batch.</p>
     */
    ErrorMessage: string | undefined;
}
export declare namespace BatchGetRecordError {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: BatchGetRecordError) => any;
}
/**
 * <p>The value associated with a feature.</p>
 */
export interface FeatureValue {
    /**
     * <p>The name of a feature that a feature value corresponds to.</p>
     */
    FeatureName: string | undefined;
    /**
     * <p>The value associated with a feature, in string format. Note that features types can be
     *          String, Integral, or Fractional. This value represents all three types as a string.</p>
     */
    ValueAsString: string | undefined;
}
export declare namespace FeatureValue {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: FeatureValue) => any;
}
/**
 * <p>The output of Records that have been retrieved in a batch.</p>
 */
export interface BatchGetRecordResultDetail {
    /**
     * <p>The <code>FeatureGroupName</code> containing Records you retrieved in a batch.</p>
     */
    FeatureGroupName: string | undefined;
    /**
     * <p>The value of the record identifer in string format.</p>
     */
    RecordIdentifierValueAsString: string | undefined;
    /**
     * <p>The <code>Record</code> retrieved.</p>
     */
    Record: FeatureValue[] | undefined;
}
export declare namespace BatchGetRecordResultDetail {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: BatchGetRecordResultDetail) => any;
}
export interface BatchGetRecordResponse {
    /**
     * <p>A list of Records you requested to be retrieved in batch.</p>
     */
    Records: BatchGetRecordResultDetail[] | undefined;
    /**
     * <p>A list of errors that have occured when retrieving a batch of Records.</p>
     */
    Errors: BatchGetRecordError[] | undefined;
    /**
     * <p>A unprocessed list of <code>FeatureGroup</code> names, with their corresponding <code>RecordIdentifier</code> value,
     *        and Feature name.</p>
     */
    UnprocessedIdentifiers: BatchGetRecordIdentifier[] | undefined;
}
export declare namespace BatchGetRecordResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: BatchGetRecordResponse) => any;
}
/**
 * <p>An internal failure occurred. Try your request again. If the problem
 *       persists, contact AWS customer support.</p>
 */
export declare class InternalFailure extends __BaseException {
    readonly name: "InternalFailure";
    readonly $fault: "server";
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InternalFailure, __BaseException>);
}
/**
 * <p>The service is currently unavailable.</p>
 */
export declare class ServiceUnavailable extends __BaseException {
    readonly name: "ServiceUnavailable";
    readonly $fault: "server";
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ServiceUnavailable, __BaseException>);
}
/**
 * <p>There was an error validating your request.</p>
 */
export declare class ValidationError extends __BaseException {
    readonly name: "ValidationError";
    readonly $fault: "client";
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ValidationError, __BaseException>);
}
export interface DeleteRecordRequest {
    /**
     * <p>The name of the feature group to delete the record from. </p>
     */
    FeatureGroupName: string | undefined;
    /**
     * <p>The value for the <code>RecordIdentifier</code> that uniquely identifies the record, in
     *          string format. </p>
     */
    RecordIdentifierValueAsString: string | undefined;
    /**
     * <p>Timestamp indicating when the deletion event occurred. <code>EventTime</code> can be
     *          used to query data at a certain point in time.</p>
     */
    EventTime: string | undefined;
}
export declare namespace DeleteRecordRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteRecordRequest) => any;
}
export interface GetRecordRequest {
    /**
     * <p>The name of the feature group in which you want to put the records.</p>
     */
    FeatureGroupName: string | undefined;
    /**
     * <p>The value that corresponds to <code>RecordIdentifier</code> type and uniquely identifies
     *          the record in the <code>FeatureGroup</code>. </p>
     */
    RecordIdentifierValueAsString: string | undefined;
    /**
     * <p>List of names of Features to be retrieved. If not specified, the latest value for all
     *          the Features are returned.</p>
     */
    FeatureNames?: string[];
}
export declare namespace GetRecordRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetRecordRequest) => any;
}
export interface GetRecordResponse {
    /**
     * <p>The record you requested. A list of <code>FeatureValues</code>.</p>
     */
    Record?: FeatureValue[];
}
export declare namespace GetRecordResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetRecordResponse) => any;
}
/**
 * <p>A resource that is required to perform an action was not found.</p>
 */
export declare class ResourceNotFound extends __BaseException {
    readonly name: "ResourceNotFound";
    readonly $fault: "client";
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ResourceNotFound, __BaseException>);
}
export interface PutRecordRequest {
    /**
     * <p>The name of the feature group that you want to insert the record into.</p>
     */
    FeatureGroupName: string | undefined;
    /**
     * <p>List of FeatureValues to be inserted. This will be a full over-write. If you only want
     *          to update few of the feature values, do the following:</p>
     *          <ul>
     *             <li>
     *                <p>Use <code>GetRecord</code> to retrieve the latest record.</p>
     *             </li>
     *             <li>
     *                <p>Update the record returned from <code>GetRecord</code>. </p>
     *             </li>
     *             <li>
     *                <p>Use <code>PutRecord</code> to update feature values.</p>
     *             </li>
     *          </ul>
     */
    Record: FeatureValue[] | undefined;
}
export declare namespace PutRecordRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: PutRecordRequest) => any;
}
